# esi-utils-time

## Introduction

Utility package to standardize time conversion functions commonly used by USGS earthquake hazard products such as ShakeMap, DYFI, and PAGER. 

For use cases, see tests directory.

## Installation

From repository base, run
```
conda create --name time pip
conda activate time
pip install -r requirements.txt .
```

## Tests

```
pip install pytest
pytest .
```
